from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFContentBlockerManager(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariApplication.getActiveWindowWithCompletionHandler_,
            0,
            b"v@",
        )
        self.assertArgIsBlock(
            SafariServices.SFSafariApplication.openWindowWithURL_completionHandler_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            SafariServices.SFSafariApplication.showPreferencesForExtensionWithIdentifier_completionHandler_,
            1,
            b"v@",
        )

        self.assertArgIsBlock(
            SafariServices.SFSafariApplication.dispatchMessageWithName_toExtensionWithIdentifier_userInfo_completionHandler_,
            3,
            b"v@",
        )

    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariApplication.getHostApplicationWithCompletionHandler_,
            0,
            b"v@",
        )

    @min_os_level("10.14.4")
    def testMethods10_14(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariApplication.getAllWindowsWithCompletionHandler_,
            0,
            b"v@",
        )

    @min_os_level("11.0")
    def testConstants11_0(self):
        self.assertIsInstance(SafariServices.SFExtensionMessageKey, str)

    @min_os_level("14.0")
    def testConstants14_0(self):
        self.assertIsInstance(SafariServices.SFExtensionProfileKey, str)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFSafariWindow(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariWindow.getActiveTabWithCompletionHandler_, 0, b"v@"
        )

        self.assertArgIsBOOL(
            SafariServices.SFSafariWindow.openTabWithURL_makeActiveIfPossible_completionHandler_,
            1,
        )
        self.assertArgIsBlock(
            SafariServices.SFSafariWindow.openTabWithURL_makeActiveIfPossible_completionHandler_,
            2,
            b"v@",
        )

        self.assertArgIsBlock(
            SafariServices.SFSafariWindow.getToolbarItemWithCompletionHandler_, 0, b"v@"
        )

    @min_os_level("10.14.4")
    def testMethods10_14(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariWindow.getAllTabsWithCompletionHandler_, 0, b"v@"
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFSafariExtensionHandlingHelper(SafariServices.NSObject):
    def validateToolbarItemInWindow_validationHandler_(self, w, h):
        pass

    def validateContextMenuItemWithCommand_inPage_userInfo_validationHandler_(
        self, a, b, c, d
    ):
        pass

    def additionalRequestHeadersForURL_completionHandler_(self, a, b):
        pass


class TestSFSafariExtensionHandling(TestCase):
    @min_os_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("SFSafariExtensionHandling")

    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            TestSFSafariExtensionHandlingHelper.validateToolbarItemInWindow_validationHandler_,
            1,
            b"vZ@",
        )

        self.assertArgIsBlock(
            TestSFSafariExtensionHandlingHelper.validateContextMenuItemWithCommand_inPage_userInfo_validationHandler_,
            3,
            b"vZ@",
        )

        self.assertArgIsBlock(
            TestSFSafariExtensionHandlingHelper.additionalRequestHeadersForURL_completionHandler_,
            1,
            b"v@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFSafariPageProperties(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertResultIsBOOL(
            SafariServices.SFSafariPageProperties.usesPrivateBrowsing
        )
        self.assertResultIsBOOL(SafariServices.SFSafariPageProperties.isActive)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFSafariExtension(TestCase):
    @min_os_level("10.14.4")
    def testMethods(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariExtension.getBaseURIWithCompletionHandler_, 0, b"v@"
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFContentBlockerManager(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(SafariServices.SFSafariServicesVersion)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(SafariServices.SFSafariServicesVersion10_0, 0)
        self.assertEqual(SafariServices.SFSafariServicesVersion10_1, 1)
        self.assertEqual(SafariServices.SFSafariServicesVersion11_0, 2)
        self.assertEqual(SafariServices.SFSafariServicesVersion12_0, 3)
        self.assertEqual(SafariServices.SFSafariServicesVersion12_1, 4)
        self.assertEqual(SafariServices.SFSafariServicesVersion13_0, 5)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFSafariExtensionManager(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            SafariServices.SFSafariExtensionManager.getStateOfSafariExtensionWithIdentifier_completionHandler_,
            1,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase

import SafariServices


class TestSFContentBlockerState(TestCase):
    def testMethods(self):
        self.assertResultIsBOOL(SafariServices.SFContentBlockerState.isEnabled)
        self.assertArgIsBOOL(SafariServices.SFContentBlockerState.setEnabled_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level

import SafariServices


class TestSFUniversalLink(TestCase):
    @min_os_level("10.15")
    def testMethods(self):
        self.assertResultIsBOOL(SafariServices.SFUniversalLink.isEnabled)
        self.assertArgIsBOOL(SafariServices.SFUniversalLink.setEnabled_, 0)
